# Change Log
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/).
This project adheres to [PEP440](https://www.python.org/dev/peps/pep-0440/)
and by implication, [Semantic Versioning](http://semver.org/).

## [0.1] - 2017-08-21
### Added
- Added get_checklist for scraping the data from the view checklist page.
- Added script so get_checklist can be called from the command line.
